pub trait DatabaseProof<'a> {
type Tx;
// Required methods
fn from_tx(tx: &'a Self::Tx) -> Self;
fn overlay_account_proof(
&self,
input: TrieInput,
address: Address,
slots: &[B256],
) -> Result<AccountProof, StateProofError>;
fn overlay_multiproof(
&self,
input: TrieInput,
targets: MultiProofTargets,
) -> Result<MultiProof, StateProofError>;
}Expand description
Extends [Proof] with operations specific for working with a database transaction.
Required Associated Types
Required Methods
Sourcefn overlay_account_proof(
&self,
input: TrieInput,
address: Address,
slots: &[B256],
) -> Result<AccountProof, StateProofError>
fn overlay_account_proof( &self, input: TrieInput, address: Address, slots: &[B256], ) -> Result<AccountProof, StateProofError>
Generates the state proof for target account based on TrieInput.
Sourcefn overlay_multiproof(
&self,
input: TrieInput,
targets: MultiProofTargets,
) -> Result<MultiProof, StateProofError>
fn overlay_multiproof( &self, input: TrieInput, targets: MultiProofTargets, ) -> Result<MultiProof, StateProofError>
Generates the state MultiProof for target hashed account and storage keys.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".